@@ -27,7 +27,8 @@ from errors import InvalidOperation, OperationFailure, AutoReconnect
 _QUERY_OPTIONS = {
     "tailable_cursor": 2,
     "slave_okay": 4,
-    "oplog_replay": 8
+    "oplog_replay": 8,
+    "no_timeout": 16
 }
 
 
@@ -36,7 +37,7 @@ class Cursor(object):
     """
 
     def __init__(self, collection, spec, fields, skip, limit, slave_okay,
-                 snapshot=False, _sock=None):
+                 timeout, snapshot=False, _sock=None):
         """Create a new cursor.
 
         Should not be called directly by application developers.
@@ -47,6 +48,7 @@ class Cursor(object):
         self.__skip = skip
         self.__limit = limit
         self.__slave_okay = slave_okay
+        self.__timeout = timeout
         self.__snapshot = snapshot
         self.__ordering = None
         self.__explain = False
@@ -90,7 +92,7 @@ class Cursor(object):
         """
         copy = Cursor(self.__collection, self.__spec, self.__fields,
                       self.__skip, self.__limit, self.__slave_okay,
-                      self.__snapshot)
+                      self.__timeout, self.__snapshot)
         copy.__ordering = self.__ordering
         copy.__explain = self.__explain
         copy.__hint = self.__hint
@@ -134,6 +136,8 @@ class Cursor(object):
         options = 0
         if self.__slave_okay:
             options |= _QUERY_OPTIONS["slave_okay"]
+        if not self.__timeout:
+            options |= _QUERY_OPTIONS["no_timeout"]
         return struct.pack("<I", options)
 
     def __check_okay_to_chain(self):
