@@ -60,7 +60,7 @@ class ObjectId(object):
         oid = ""
 
         # 4 bytes current time
-        oid += struct.pack("<i", int(time.time()))
+        oid += struct.pack(">i", int(time.time()))
 
         # 3 bytes machine
         machine_hash = _md5func()
@@ -68,11 +68,11 @@ class ObjectId(object):
         oid += machine_hash.digest()[0:3]
 
         # 2 bytes pid
-        oid += struct.pack("<H", os.getpid() % 0xFFFF)
+        oid += struct.pack(">H", os.getpid() % 0xFFFF)
 
         # 3 bytes inc
         ObjectId._inc_lock.acquire()
-        oid += struct.pack("<i", ObjectId._inc)[0:3]
+        oid += struct.pack(">i", ObjectId._inc)[1:4]
         ObjectId._inc = (ObjectId._inc + 1) % 0xFFFFFF
         ObjectId._inc_lock.release()
 
@@ -98,25 +98,53 @@ class ObjectId(object):
             raise TypeError("id must be an instance of (str, ObjectId), "
                             "not %s" % type(oid))
 
-    def url_encode(self):
+    def url_encode(self, legacy=False):
         """Get a string representation of this ObjectId safe for use in a url.
 
-        The reverse can be achieved using `url_decode()`.
-        """
-        return self.__id.encode("hex")
+        The `legacy` parameter is for backwards compatibility only and should
+        almost always be kept False. It might eventually be removed.
 
-    def url_decode(cls, encoded_oid):
+        The reverse can be achieved using `url_decode()`.
+
+        :Parameters:
+          - `legacy` (optional): use the legacy byte ordering to represent the
+            ObjectId. if you aren't positive you need this it is probably best
+            left as False.
+        """
+        if legacy:
+            return self.legacy_str().encode("hex")
+        else:
+            return self.__id.encode("hex")
+
+    def url_decode(cls, encoded_oid, legacy=False):
         """Create an ObjectId from an encoded hex string.
 
+        The `legacy` parameter is for backwards compatibility only and should
+        almost always be kept False. It might eventually be removed.
+
         The reverse can be achieved using `url_encode()`.
 
         :Parameters:
           - `encoded_oid`: string encoding of an ObjectId (as created
             by `url_encode()`)
+          - `legacy` (optional): use the legacy byte ordering to represent the
+            ObjectId. if you aren't positive you need this it is probably best
+            left as False.
         """
-        return cls(encoded_oid.decode("hex"))
+        if legacy:
+            oid = encoded_oid.decode("hex")
+            return cls.from_legacy_str(oid)
+        else:
+            return cls(encoded_oid.decode("hex"))
     url_decode = classmethod(url_decode)
 
+    def legacy_str(self):
+        return self.__id[7::-1] + self.__id[:7:-1]
+
+    def from_legacy_str(cls, legacy_str):
+        return cls(legacy_str[7::-1] + legacy_str[:7:-1])
+    from_legacy_str = classmethod(from_legacy_str)
+
     def __str__(self):
         return self.__id
 
